/************************ PRODUCT VALIDATION  ******************
 *
 *      NAME: DemographicsDistribution_ADSL001.sas
 *    REPORT: Demographic Distribution JMPC7.1
 *   PURPOSE: Demographic Distribution Validation Program on Nicardipine Study
 *   DEFECTS: 
 *     NOTES:  Use  Actual treatment Safety Population
 *	   NOTES: NO Discrepancy between JMPC Results and Validation Results
 *****************************************************************/
title1 'DemographicsDistribution_ADSL001.sas: DM Distribution Validation Program';

libname sdtm "&SDTMPATH";
libname adam "&ADAMPATH";

data adsl;
 set adam.adsl;
 where saffl='Y' and trt01p ne 'Screen Failure';
run;

*** Age category variables creation ***;
data age_adsl;
 length agecat1 $100;
 set adsl;

 if .<age<40 then agecat1='Age 39 or younger';
  else if 40<=age<=64 then agecat1='Age between 40 and 64';
  else if age>=65 then agecat1='Age 65 and older';
run;


proc sort data=age_adsl; by trt01p; run;

****distribution tables without treatment comparison variable***;

proc freq data=age_adsl ;
table trt01p agecat1 sex race trt01p siteid country;
run;

****distribution tables by treatment comparison variable***;
proc freq data=age_adsl ;
 by trt01p;
 table agecat1/out=agecat1; 
run;


proc means data=age_adsl ;
 by trt01p;
 var age;
 output out=age_means n=n mean=mean std=std median=median q1=q1 q3=q3 min=min max=max;
run; 

proc print data=age_means;
run;

proc means data=age_adsl noprint;
 var age;
 output out=age_means2 n=n mean=mean std=std stderr=stderr lclm=lclm uclm=uclm;
run; 

proc print data=age_means2;
run;

*** Summary Statistics on Sex ***;
proc freq data=age_adsl noprint;
 by trt01p;
 table sex /out=sex1;
run;

proc freq data=age_adsl noprint;
 table sex/out=sex2;
run;

*** Summay Statistics on Race ***;
proc freq data=age_adsl noprint;
 by trt01p;
 table race /out=race1;
run;

proc freq data=age_adsl noprint;
 table race/out=race2;
run;

*** Summary Statistics on Site ID ***;
proc freq data=age_adsl noprint;
 by trt01p;
 table siteid /out=site1;
run;

proc freq data=age_adsl noprint;
 table siteid/out=site2;
run;

*** Age ANOVA ***;
proc anova data=age_adsl;
 class trt01p;
 model age=trt01p;
 means trt01p/t clm;
run;
quit;

*** Age Pooled t-test ***;
proc ttest data=age_adsl;
 class trt01p;
 var age;
run;

*** Sex Contingency Analysis ***;
proc freq data=age_adsl;
 tables trt01p*sex/fisher plots=mosaic;
 exact pchi lrchi;
run;

*** Race Contingency Analysis ***;
proc freq data=age_adsl;
 tables trt01p*race/fisher plots=mosaic;
 exact pchi lrchi;
run;

**** Create Summary of Demographics With Proc Tabulate ****;
options nodate nonumber missing =' ';

filename pdfOutF "&OUTPUTD/DemographicsDistribution.pdf";

ods escapechar= '#';
ods pdf style=htmlblue file =pdfOutF;

proc tabulate data = age_adsl missing;
class trt01p agecat1 sex race siteid ;
var age ;
table age= 'Age' *(
	n='N'*f=8. 
	mean= 'Mean'*f=5.2
	std='Std Dev'*f=5.2
	min='Min' * f=8.
	Q1='Quantile25' * f=8.
	Median ='Median' *f=8.
	Q3='Quantile75 ' * f=8.
	max='Max' * f=8.)
	agecat1= 'Age Group' * (n='n' * f=3. colpctn= '%' * f=4.1)
	sex ='Sex' * (n='n' * f=3. colpctn= '%' * f=4.1)
	race = 'Race' * (n= 'n' *f=3. colpctn= '%' * f=4.1)
	siteid= 'Study Site Identifier' * (n='n' * f=3. colpctn= '%' * f=4.1),
    (trt01p=" ")(all="Overall");
title3 j=c 'Demographics Distribution';
run;

ods pdf close;
