/************************ PRODUCT VALIDATION ******************
 *
 *      NAME: FindingsShiftPlots_LB001.sas
 *    REPORT: Findings Shift Plots JMPC 7.1
 *   PURPOSE: Findings Shift Plots Validation Program For Nicardipine study
 *   DEFECTS: 
 *     NOTES: LB, SAFETY Popluation,  Actural Treatment, ULN Normalization,
 *     NOTES: log2 Transformation of Lab Measurements
 *     NOTES: use Mean for multiple measurements on the same visitnum
 *     NOTES: Same Results as JMPC
 
 *****************************************************************/

title1 'FindingsShiftPlots_LB001.sas:  Laboratory Test Results Shift Plots Validation Program';
title2 "Trial Mean as finding measurements, ULN Normalization , log2 Transformation";

*option mprint symbolgen;

libname sdtm "&SDTMPATH";
libname adam "&ADAMPATH";

*** Subset ADSL on safety population ***;
data adsl;
	set adam.adsl;
 	where saffl='Y' and trt01p ne 'Screen Failure';
run;


*** 64355 obs in lb data and in adsl;
data lb; 
	merge adsl(in=inadsl keep=usubjid trt01p trt01pn) sdtm.lb(in=inlb);
	by usubjid;
	if inadsl and inlb;
run;


**** create Trial subset-- lab data by  EACH LBtestcd without BASELINE;
**** use mean for multiple measurements on the same usubjid lbtestcd;
**** Not mean group by  LBDY;
**** Get mean for Trial  where LBBLFL ^= Y;
proc sql;
	create table LB_data_nobase as
	select  distinct usubjid, lbtestcd, trt01p, mean(log2(lbstresn/lbstnrhi))
            as TrialMean
	from lb
	where LBBLFL ^='Y'
	group by usubjid, lbtestcd;
quit;


/*** check number of Individuals in LB dataset and in Trial subset;
proc sql; 
select count ( distinct usubjid) as nobs_in_LB 
 from lb;
select count(distinct usubjid) as nobs_in_trial from LB_data_nobase;
quit;
***/

**** create Trial results Elevation category indicators;
data LB_data_nobase; set LB_data_nobase;
length Trial_Elevation $25;
if missing(TrialMean) then Trial_Elevation = "06 Missing";
else if TrialMean < Log2(2) then Trial_Elevation = "01 Less than 2x ULN";
else if Log2(2) <= TrialMean < Log2(5) then Trial_Elevation = "02 2x and 5x ULN";
else if Log2(5) <= TrialMean < Log2(10) then Trial_Elevation = "03 5x and 10x ULN";
else if Log2(10) <= TrialMean < Log2(20) then Trial_Elevation= "04 10x and 20x ULN";
else Trial_Elevation = "05 20x ULN or Greater";
run;


proc format;
value $cat 
"01 Less than 2x ULN" ='Less than 2x ULN'
"02 2x and 5x ULN" = '2x and 5x ULN'
"03 5x and 10x ULN" = '5x and 10x ULN'
"04 10x and 20x ULN" ='10x and 20x ULN'
"05 20x ULN or Greater"='20x ULN or Greater'
"06 Missing " ='Missing';
run;


**** create baseline dataset using LBBLFL=Y and last obs;
proc sql; 
	create table base_set1 as
	select usubjid, lbtestcd, mean(log2(lbstresn/lbstnrhi)) as nm_baseline, trt01p, visitnum, LBDY
	from lb
    where   LBBLFL='Y'
	group by usubjid, lbtestcd, visitnum, LBDY
	order by usubjid ,lbtestcd, visitnum, LBDY;
quit;

**** Calculate baseline as Last recorded pre-dose measurement;
**** keep last obs of baseline as single value for baseline;
data baseline_set; set base_set1;
	by usubjid lbtestcd LBDY;
	if last.lbtestcd;
	drop LBDY visitnum ;
run;

**** create baseline Elevation category indicators;
data baseline_set; set baseline_set;
length Baseline_Elevation $25;
if missing(nm_baseline) then Baseline_Elevation = "06 Missing";
else if nm_baseline < Log2(2) then Baseline_Elevation = "01 Less than 2x ULN";
else if Log2(2) <= nm_baseline < Log2(5) then Baseline_Elevation = "02 2x and 5x ULN";
else if Log2(5) <= nm_baseline < Log2(10) then Baseline_Elevation = "03 5x and 10x ULN";
else if Log2(10) <= nm_baseline < Log2(20) then Baseline_Elevation= "04 10x and 20x ULN";
else Baseline_Elevation = "05 20x ULN or Greater";
run;

proc sort data=LB_data_nobase; by usubjid lbtestcd; run;
proc sort data=baseline_set; by usubjid lbtestcd; run;

**** 23016 obs;
data LB_comb; merge baseline_set LB_data_nobase; 
by usubjid lbtestcd;
run;

**** transpose table to get the same data structure  as JMPC;
proc transpose data=LB_comb out=TrialMean_rec (drop= _name_) suffix=_Log2_TrialMean_ULN_ ;
by usubjid trt01p ;
var TrialMean ;
id lbtestcd;
run;

proc transpose data=LB_comb out=baseline_rec (drop= _name_) suffix=_Log2_baseline_ULN_;
by usubjid trt01p ;
var nm_baseline;
id lbtestcd;
run;

**** merge baseline and trial datset;
**** 901 subjects;
data LB_comb_rec;
merge TrialMean_REC baseline_REC;
by usubjid;
RUN;


libname outdata "&OUTPUTD";
data outdata.FindingsShiftPlots_LB001;
 set LB_comb_rec;
run;



**** create dataset to generate Laboratory Test Results Shift Tables;
proc sql;
create table LB_test_cross as
select a.usubjid, a.lbtestcd,b.Trial_Elevation, b.Baseline_Elevation from 
(select * from 
(select distinct usubjid from LB_comb) 
 cross join
(select distinct lbtestcd from LB_comb )) as a
left join
LB_comb b 
on a.usubjid =b.usubjid & a.lbtestcd=b.lbtestcd 
order by lbtestcd, usubjid;
quit;

data LB_test_cross; set LB_test_cross; 
by lbtestcd usubjid;
if Trial_Elevation = "" then Trial_Elevation="06 Missing";
if Baseline_Elevation="" then Baseline_Elevation="06 Missing";
run;

options nodate nonumber missing = ' ';

filename pdfOutF "&OUTPUTD/FindingsShiftPlots_LB001.pdf";

ods _all_ close;
ods escapechar='#';
ods pdf style =htmlblue file=pdfOutF
	 startpage=no;
*ods graphics/ attrpriority=none height=4in width=7in;

%macro sgpt(testcd);

title3 " &testcd Shift Plots Trial Mean  vs Baseline ";

proc sgplot data=lb_comb_rec aspect=1;
	styleattrs datasymbols=( trianglefilled circlefilled);
	scatter x= &testcd._Log2_baseline_ULN_  y= &testcd._Log2_TrialMean_ULN_/group=trt01p;
 
	yaxis 
		label ="  &testcd Log2(TrialMean/ULN) ";
	xaxis 
		label = " &testcd Log2(Baseline/ULN)";
	lineparm x=0 y=0 slope=1; 
	/** intercept, slope **/
     xaxis grid; yaxis grid;

	keylegend / exclude=("LineParm") location=inside position=bottomright across=1;
run;

title3;
%mend;


**** get all TEST NAMES ***;
proc sql;
	create table test as
	select distinct lbtestcd
	from lb;
quit;

data test; set test;
if lbtestcd='' then delete;
run;

data _null_;
set test nobs=number;
if _n_=1 then call symputx('num_tst', number);
call symputx( cats('tst', _n_), lbtestcd);
run;

%macro one;
	%do i =1 %to &num_tst;
 		%sgpt(&&tst&i);
	%end;
%mend;

*%sgpt(AST);

%one;


proc freq data=LB_test_cross ;
tables Trial_Elevation * Baseline_Elevation/nocum norow nocol;
format Baseline_Elevation  $cat.;
format Trial_Elevation $cat.;
by lbtestcd;
run;

ods pdf close;


