/************************ PRODUCT VALIDATION  ******************
 *
 *      NAME: MortalityTimetoEvent_DS001.sas
 *    REPORT: Mortality Time to Event JMPC 7.1
 *   PURPOSE: Mortality Time to Event Validation Program For Nicardipine study
 *     NOTES: SAFETY Popluation, Actural Treatment
 *     Notes: Define Last Disposition Record Date as censor date
 *     Notes:  
 *   Results: SAME Results as JMPC with hotfix
 *
 *****************************************************************/
title1 'MortalityTimetoEvent_DS001.sas: Mortality Time to Event Validation Program';
title2 'SAFETY Popluation, Actural Treatment, Last Disposition Date as censor date';


libname sdtm "&SDTMPATH";
libname adam "&ADAMPATH";

data adsl;
 set adam.adsl;
 where saffl='Y' and trt01p ne 'Screen Failure';
 if .<age<=39 then agegrp="1";
  else if 39<age<=64 then agegrp="2";
  else if 64<age then agegrp="3";
run;

data dm;
	set sdtm.dm (keep=usubjid RFSTDTC RFENDTC);
run;

data adsl; merge adsl (in=inadsl) dm;
by usubjid;
if inadsl;
run;


proc sql noprint;
	select count(distinct usubjid) format=3.
		into :n_placebo
		from adsl
		where trt01pn=0;
    select count(distinct usubjid) format=3.
		into :n_nic
		from adsl
		where trt01pn=1;
quit;


*Define Last Disposition Record Date as censor date;
%let censor_date=dsstdtc;

**** Mortality Time To Event only consider death as disposition event **;

data ds;
 set sdtm.ds(where=(dscat='DISPOSITION EVENT'));
 keep usubjid dscat dsdecod dsstdtc;
run;

**** merge with adsl **;
data adsl_ds; merge adsl (in=in1) ds (in=in2 keep=usubjid dsdecod dsstdtc);
by usubjid;
if  upcase(dsdecod)='DEATH' then death=1;
   else death=0;
if in1;
run;


*** Check contingency table***;
*** Mosaic plot  ***;
*** Overall counts of death occurrence regardless of Censor Date;
*** Same Results as JMPC , 161 death occurance ***;
ods listing gpath="&OUTPUTD";
title3 'Overall counts of death occurrence regardless of Censor Date';
ods graphics on;
proc freq data=adsl_ds;
 tables death *trt01p/ chisq plots=MOSAIC;
run;
title3;
ods listing close;


**** Use censor date ***;
****;
data adsl_ds_time;
set adsl_ds;
 if death=1 & input(dsstdtc,yymmdd10.) <= input(&censor_date,yymmdd10.) then 
     do;
	    atime=input(dsstdtc,yymmdd10.) - input(rfstdtc,yymmdd10.)+1;
		CNSR=0; failed=1;
	 end;
 if ( death=1 & input(dsstdtc,yymmdd10.) > input(&censor_date,yymmdd10.) ) 
        or death=0 then 
     do;
	    atime=input(&censor_date,yymmdd10.)- input(rfstdtc,yymmdd10.)+1;
	  	CNSR=1; failed =0;
     end;
run;


ods listing gpath="&OUTPUTD";
*ods output CensoredSummary=events;
ods output HomTests=teststats;
*ods output Means=means;
ods output Quartiles=quartiles;
*ods output ProductLimitEstimates=estimate;

title3 "Censor Date Determined using &censor_date";
proc lifetest data=adsl_ds_time method=pl plots=survival(cb atrisk);
 time atime*CNSR(1);
 strata trt01p / test=logrank wilcoxon;
run;


*** Mosaic plot  ***;
ods graphics on;
proc freq data=adsl_ds_time;
 tables cnsr*trt01p / chisq plots=MOSAIC;
run;


*** PROC PHREG ***;
*** unstratified analysis;
ods output HazardRatios=hr;
proc phreg data=adsl_ds_time;
 class trt01p(ref="Placebo");
 model atime*cnsr(1)=trt01p;
 hazardratio trt01p/ diff=ref;
run;
ods listing close;
*** check overall survival analysis table ***;
*** use last disposition event before censor date to categorize censored obs***;
*** 741 obs censored , 161 obs death before censor date ***;

data ds; set sdtm.ds;
run;

*** Subjects were censored using Censor Date***;
*** 3447 obs retained with dsstdtc <= censor date ***;
*** Retain last DS record before or on the censor date;
data ds_; merge ds adsl(in=inadsl);
by usubjid;
if  inadsl;
dsdtc=input(scan(dsstdtc,1,'T'),yymmdd10.);
if dsdtc>input(&censor_date,yymmdd10.) then delete;
run;

proc sort data=ds_;
by usubjid dsstdtc dsseq;
run;

data ds_; set ds_;
by usubjid;
if last.usubjid;
run;



**** macro to generate report data from proc freq CrossTabFreqs tables;
%macro freq_report(dsn,var1, var2);
ods listing close;
ods  output CrossTabFreqs=counts;
proc freq data= &dsn;
tables &var1 * &var2;
run;
ods output close;

data section; set counts (keep=&var1 &var2 Frequency ColPercent) ;
if &var1 ne '' and &var2 ne '';
run;

proc sort data=section;
by &var1;
run;

proc transpose data=section out=s_1 prefix=freq;
 by &var1;
 var frequency;
 id &var2;
run; 

proc transpose data=section out=s_2 prefix=perc;
 by &var1;
 var Colpercent;
 id &var2;
run; 

data section; merge s_1 (drop=_name_ _label_) s_2 (drop=_name_ _label_);
run;
ods listing;

%mend;


**** generate report data for section1;
%freq_report(adsl_ds_time, cnsr,trt01p);

 data section1_1; set section;
  length dsdecod $20;
  if CNSR=1 then dsdecod="CENSORED";
  if CNSR=0 then dsdecod="DEATH" ;
 run;

%freq_report(ds_, dsdecod, trt01p);

data section1_2;
set section;
CNSR=1;
where dsdecod ne "DEATH";
run;

*** generate report data for section1;
data section1; set section1_1 section1_2 ;
run;

**** generate report data for Quantiles;
data Quart (keep= trt01p Percent estimate CI);
set Quartiles;
CI= "(" || put(LowerLimit, 4.) || "," ||  put(UpperLimit, 4.1) || ")";
run;

proc sort data=quart;
by  percent;
run;

proc transpose data=quart out=section2_1 prefix=est;
by percent;
ID  trt01p ;
var estimate ;
run;

proc transpose data=quart out=section2_2 prefix=CI ;
by percent;
ID  trt01p ;
var CI ;
run;

data section2 ; merge section2_1 section2_2;
by percent;
drop _name_ _label_;
run;





**** Hazard Ratio for Subgroup;
%macro hr(byvar);
proc sort data=adsl_ds_time ; by &byvar;
run;

ods output HazardRatios=hr_&byvar;
proc phreg data=adsl_ds_time;
     by &byvar.;
 class trt01p(ref="Placebo");
 model atime*cnsr(1)=trt01p;
 hazardratio trt01p/ diff=ref;
run;

ods  output CrossTabFreqs=counts_&byvar;
proc freq data=adsl_ds_time;
tables &byvar. * trt01p*death;
run;

data counts_&byvar (keep= &byvar trt01p death frequency); set counts_&byvar( where =(Death ne 0 ));
if trt01p ne "";
run;

proc transpose data= counts_&byvar out= ct_&byvar (drop=_name_ _label_);
var frequency;
by &byvar.;
run;

data ct2_&byvar;
set ct_&byvar;
set hr_&byvar(keep=HazardRatio WaldLower WaldUpper ) ;
run;

%if &byvar= agegrp %then %do;
data comb;
length demosub $20;
set ct2_&byvar;
 section="&byvar.";
 demosub= &byvar.; 
 drop &byvar;
run;
%end;
%else %do;
data comb (drop= &byvar.); set  comb ct2_&byvar (in=ina );
if ina then section="&byvar.";
if ina then demosub= &byvar.;
run;
%end;
%mend;

%hr(agegrp);
%hr(sex);
%hr(Race);
%hr(country);
%hr(siteid);

proc format;
value $agegrp
  "1"= " 0<=Age<=39"
  "2"= " 39<Age<=64"
  "3"= " Age>64";
run;

data comb ;set comb;
CI_HR= "(" || put(WaldLower,6.3) || "," || put(WaldUpper,6.3) || ")";
run;

proc report data= comb
nowindows split="|";;
	columns ("" section demosub) ("NIC.15|N=&n_nic " col1 col2) 
        ("Placebo |N=&n_placebo" col3 col4) ("NIC .15 vs Placebo"  HazardRatio  CI_HR);

define section / group order " " ;
define demosub /display "Demographic Subgroup" format= $agegrp.;
define col1/display  center width=14 "Event Counts";
define col2/display  center width=14 "Subgroup Counts";
define col3/display  center width=14 "Event Counts";
define col4/display  center width=14 "Subgroup Counts";
define HazardRatio/ display center width= 6 "Hazard Ratio";
define CI_HR/ display center width= 14 "Confidence Interval";
run;


**** Use Proc Report to write stat Tables to file;
options nodate nonumber missing = ' ';

filename pdfOutF "&OUTPUTD/MortalityTimetoEvent_DS001.pdf";

ods escapechar='#';
ods pdf style =htmlblue file=pdfOutF
       startpage=no;

proc report data=section1
	nowindows
	split="|";
	
	columns cnsr dsdecod ("NIC.15 " freqNic__15 percNic__15) 
        ("Placebo" freqPlacebo percPlacebo) ;
    define cnsr / order noprint;
	define dsdecod / width =14 "Overall Survival";
	define freqNic__15  /display center width=14 "Count";
	define percNic__15 /display center width=14 "%";
	define freqPlacebo /display center width=14 "Count";
	define percPlacebo /display center width=14 "%";
	
title3 j=c 'Overall survival Analysis By treatment ';
run;

proc report data=section2
	nowindows
	split="|";
	
	columns ( "Kaplan-Meier estimate of overall surviva" Percent ("NIC.15 " estNic__15 CINic__15) 
        ("Placebo" estPlacebo CIPlacebo)) ;

	define Percent /order width =14 "Quantile";
	define estNic__15  /display center width=14 "Estimate";
	define CINic__15 /display center width=14 "CI";
	define estPlacebo /display center width=14 "Estimate";
	define CIPlacebo /display center width=14 "CI";
run;


data hr ;set hr;
CI_HR= "(" || put(WaldLower,6.3) || "," || put(WaldUpper,6.3) || ")";
run;

proc report data=hr
	nowindows
	split="|";
	columns ("Unstratified Analysis" Description HazardRatio CI_HR );
	define Description /display width =24;
	define HazardRatio  /display center width=14 "HazardRatio" ;
	define CI_HR /display center width=20 "95 % CI";

run;


proc report data=teststats (obs=1)
	nowindows
	split="|";
	columns test   ProbChiSq;   
	define test /display width =14  ;
	define probChisq  /display center width=14 ;
	
run;


proc report data= comb
nowindows split="|";;
	columns ("" section demosub) ("NIC.15|N=N_nic " col1 col2) 
        ("Placebo |N=N_Placebo" col3 col4) ("NIC .15 vs Placebo"  HazardRatio  CI_HR);

define section / group order " " ;
define demosub /display "Demographic Subgroup" format= $agegrp.;
define col1/display  center width=14 "Event Counts";
define col2/display  center width=14 "Subgroup Counts";
define col3/display  center width=14 "Event Counts";
define col4/display  center width=14 "Subgroup Counts";
define HazardRatio/ display center width= 6 "Hazard Ratio";
define CI_HR/ display center width= 14 "Confidence Interval";
run;

ods pdf close;
